"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const helper_1 = require("./helper");
const publishResponseResponse = {};
const publish = jest.fn().mockImplementation(() => {
    return Promise.resolve(publishResponseResponse);
});
jest.mock('@aws-sdk/client-sns', () => {
    return {
        SNS: jest.fn().mockImplementation(() => {
            return {
                publish,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const snsHelperMock = new helper_1.SNSHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.SNSHelper.name}.${snsHelperMock.PublishAsync.name}`, () => {
    const action = `${helper_1.SNSHelper.name}.${snsHelperMock.PublishAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} topicArn`, () => {
        const actual = snsHelperMock.PublishAsync(TestValues.EmptyString, TestValues.Subject, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} topicArn`);
    });
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = snsHelperMock.PublishAsync(TestValues.Arn, TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} message`, () => {
        const actual = snsHelperMock.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} message`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = snsHelperMock.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.Body);
        return expect(actual).resolves.toEqual(publishResponseResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map