"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SNSHelper = void 0;
const SNS = require("@aws-sdk/client-sns");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class SNSHelper extends typescript_helper_functions_1.BaseClass {
    Repository;
    Options;
    constructor(logger, repository, options) {
        super(logger);
        this.Options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            :
                options;
        this.Repository = repository || new SNS.SNS(this.Options);
    }
    async PublishAsync(topicArn, subject, message, messageAttributes) {
        const action = `${SNSHelper.name}.${this.PublishAsync.name}`;
        this.LogHelper.LogInputs(action, {
            topicArn,
            subject,
            message,
            messageAttributes,
        });
        if (this.ObjectOperations.IsNullOrWhitespace(topicArn)) {
            throw new Error(`[${action}]-Must supply topicArn`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(subject)) {
            throw new Error(`[${action}]-Must supply subject`);
        }
        if (this.ObjectOperations.IsNullOrWhitespace(message)) {
            throw new Error(`[${action}]-Must supply message`);
        }
        const params = {
            Message: message,
            MessageAttributes: messageAttributes,
            Subject: subject,
            TopicArn: topicArn,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.publish(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
}
exports.SNSHelper = SNSHelper;
//# sourceMappingURL=helper.js.map